JsonModel class abstract
- Mixed-in types
Constructors
- JsonModel()
-
JsonModel.fromEntries(Map<
String, dynamic> opts) - JsonModel.fromJson(String opts)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromEntries(
Map< String, dynamic> entries) → dynamic -
inherited
-
fromJson(
String opts) → dynamic -
inherited
-
getValue<
T> (dynamic reflectee, Symbol key, dynamic value) → dynamic -
inherited
-
isIdentical(
Object o) → dynamic -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseObject(
dynamic reflectee, Map< String, dynamic> parsed) → dynamic -
inherited
-
toJson(
) → Map< String, dynamic> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited